<?php

/* Reminder: always indent with 4 spaces (no tabs). */
// +---------------------------------------------------------------------------+
// | Flickr plugin 0.2                                                         |
// +---------------------------------------------------------------------------+
// | functions.inc                                                             |
// |                                                                           |
// | This file does two things: 1) it implements the necessary Geeklog Plugin  |
// | API method and 2) implements all the common code needed by the Flick      |
// | plugin's PHP files.                                                       |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2006 by the following authors:                              |
// |                                                                           |
// | Authors: Dirk Haun        - dirk AT haun-online DOT de                    |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+
// 
// $Id: functions.inc,v 1.4 2006/04/01 22:44:59 dirk Exp $

require_once ($_CONF['path'] . 'plugins/flickr/config.php');
 
// This is the Flickr API key for the Geeklog Flickr plugin.
// Should you create any derived work from this plugin, please get your own
// API key (it's free) from http://www.flickr.com/services/api/
define ('FLICKR_API_KEY', '8b172ed890f21a3e28d11d30903bfc49');

/**
* This is pretty much everything the plugin actually does:
*
* Implements handling of the [flickr:] autotag
*
*/
function plugin_autotags_flickr ($op, $content = '', $autotag = '')
{
    global $_CONF, $_FL_CONF, $_DB_host, $_DB_name, $_DB_user, $_DB_pass;

    if ($op == 'tagname') {

        return 'flickr';

    } else if ($op == 'parse') {

        static $flickr;

        require_once ($_CONF['path'] . 'plugins/flickr/include/phpFlickr.php');

        if (!isset ($flickr)) {
            $flickr = new phpFlickr (FLICKR_API_KEY, NULL, false);

            if ($_FL_CONF['use_cache']) {
                if ($_FL_CONF['cache_type'] == 'db') {
                    $flickr->enableCache ('db',
                            "mysql://$_DB_user:$_DB_pass@$_DB_host/$_DB_name",
                            $_FL_CONF['cache_expiration'],
                            $_FL_CONF['cache_table_name']);
                } else {
                    // phpFlickr prefers its paths without a trailing slash
                    if (substr ($_FL_CONF['cache_fs_name'], -1) == '/') {
                        $_FL_CONF['cache_fs_name']
                                = substr ($_FL_CONF['cache_fs_name'], 0, -1);
                    }
                    $flickr->enableCache ('fs', $_FL_CONF['cache_fs_name'],
                                          $_FL_CONF['cache_expiration']);
                }
            }
        }

        $id = $autotag['parm1'];
        $title = '';

        $photoalign = '';           // default alignment: none
        $photosize = 'Thumbnail';   // default photo size
        if (!empty ($autotag['parm2'])) {
            $skip = 0;
            $px = explode (' ', trim ($autotag['parm2']));
            if (is_array ($px)) {
                foreach ($px as $part) {
                    if (substr ($part, 0, 6) == 'align:') {
                        $a = explode (':', $part);
                        $a = strtolower ($a[1]);
                        if (($a == 'left') || ($a == 'right')) {
                            $photoalign='align="' . $a . '" ';
                        }
                        $skip++;
                    } else if (substr ($part, 0, 5) == 'size:') {
                        $s = explode (':', $part);
                        $s = strtolower ($s[1]);
                        if (($s == 'square') || ($s == 'thumbnail') ||
                                ($s == 'small') || ($s == 'medium')) {
                            $photosize = ucwords ($s);
                        }
                        $skip++;
                    } else {
                        break;
                    }
                }
                if ($skip == 0) {
                    $title = trim ($autotag['parm2']);
                } else {
                    if (count ($px) > $skip) {
                        for ($i = 0; $i < $skip; $i++) {
                            array_shift ($px);
                        }
                        $title = trim (implode (' ', $px));
                    }
                }
            } else {
                $title = trim ($autotag['parm2']);
            }
        }

        $thumbnail = '';
        $photopage = '';

        $info = $flickr->photos_getInfo ($id);

        if (empty ($title) && !empty ($info['title'])) {
            $title = $info['title'];
        }

        $urls = $info['urls']['url'];
        if (is_array ($urls)) {
            foreach ($urls as $url) {
                if ($url['type'] == 'photopage') {
                    $photopage = $url['_value'];
                    break;
                }
            }
        }

        if (!empty ($photopage)) {
            $sizes = $flickr->photos_getSizes ($id);

            foreach ($sizes as $size) {
                if ($size['label'] == $photosize) {
                    $thumbnail = '<img src="' . $size['source'] . '" width="'
                        . $size['width'] . '" height="' . $size['height'] . '" '
                        . 'border="0" ' . $photoalign . 'alt="' . $title
                        . '" title="' . $title . '" class="flickr-photo">';
                    break;
                }
            }
        }

        if (!empty ($thumbnail) && !empty ($photopage)) {
            $piclink = '<a href="' . $photopage . '">' . $thumbnail . '</a>';
            $content = str_replace ($autotag['tagstr'], $piclink, $content);
        }

        return $content;
    }
}

function plugin_geticon_flickr ()
{
    global $_CONF;

    return $_CONF['site_admin_url'] . '/plugins/flickr/images/flickr.png';
}

function plugin_chkVersion_flickr ()
{
    global $_FL_CONF;

    return $_FL_CONF['version'];
}

function plugin_upgrade_flickr ()
{
    global $_TABLES;

    $v = DB_getItem ($_TABLES['plugins'], 'pi_version', "pi_name = 'flickr'");
    $nv = plugin_chkVersion_flickr ();

    if ($v != $nv) {
        $nv = addslashes ($nv);
        DB_query ("UPDATE {$_TABLES['plugins']} SET pi_version = '$nv' WHERE pi_name = 'flickr'");
    }

    return true;
}

function plugin_uninstall_flickr ()
{
    global $_TABLES, $_FL_CONF;

    // drop cache table - ignore errors
    DB_query ("DROP TABLE {$_FL_CONF['cache_table_name']}", 1);

    DB_query ("DELETE FROM {$_TABLES['plugins']} WHERE pi_name = 'flickr'");

    return true;
}

?>
